def count_vowels(string):
    return sum(1 for char in string.lower() if char in 'aeiou')

def reverse_string(string):
    return string[::-1]

def is_palindrome(string):
    return string.lower() == string.lower()[::-1]


from setuptools import setup

setup(
    name='UCI_Package',
    version='0.1.0',
    description='Utilities from DCI Class',
    author='Ibad',
    packages=['UCI_Package'],
    python_requires='>=3.6',
    install_requires=[],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
